@@ -57,7 +57,7 @@
 #define GEDIT_IS_CLOSING_ALL            "gedit-is-closing-all"
 #define GEDIT_IS_QUITTING 	        "gedit-is-quitting"
 #define GEDIT_IS_CLOSING_TAB		"gedit-is-closing-tab"
-
+#define GEDIT_IS_QUITTING_ALL		"gedit-is-quitting-all"
 
 static void tab_state_changed_while_saving (GeditTab    *tab,
 					    GParamSpec  *pspec,
@@ -79,27 +79,22 @@ get_tab_from_file (GList *docs, GFile *file)
 
 	while (docs != NULL)
 	{
-		gchar *u;
 		GeditDocument *d;
+		GFile *l;
 
 		d = GEDIT_DOCUMENT (docs->data);
 
-		u = gedit_document_get_uri (d);
-		if (u != NULL)
+		l = gedit_document_get_location (d);
+		if (l != NULL)
 		{
-			GFile *f;
-
-			f = g_file_new_for_uri (u);
-			g_free (u);
-
-			if (g_file_equal (f, file))
+			if (g_file_equal (l, file))
 			{
 				tab = gedit_tab_get_from_document (d);
-				g_object_unref (f);
+				g_object_unref (l);
 				break;
 			}
 
-			g_object_unref (f);
+			g_object_unref (l);
 		}
 
 		docs = g_list_next (docs);
@@ -125,9 +120,10 @@ is_duplicated_file (GSList *files, GFile *file)
 /* File loading */
 static gint
 load_file_list (GeditWindow         *window,
-		GSList              *files,
+		const GSList        *files,
 		const GeditEncoding *encoding,
 		gint                 line_pos,
+		gint                 column_pos,
 		gboolean             create)
 {
 	GeditTab      *tab;
@@ -135,7 +131,7 @@ load_file_list (GeditWindow         *window,
 	gboolean       jump_to = TRUE; /* Whether to jump to the new tab */
 	GList         *win_docs;
 	GSList        *files_to_load = NULL;
-	GSList        *l;
+	const GSList  *l;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -197,16 +193,15 @@ load_file_list (GeditWindow         *window,
 		if (gedit_document_is_untouched (doc) &&
 		    (gedit_tab_get_state (tab) == GEDIT_TAB_STATE_NORMAL))
 		{
-			gchar *uri;
-
-			// FIXME: pass the GFile to tab when api is there
-			uri = g_file_get_uri (l->data);
 			_gedit_tab_load (tab,
-					 uri,
+					 l->data,
 					 encoding,
 					 line_pos,
+					 column_pos,
 					 create);
-			g_free (uri);
+			
+			/* make sure the view has focus */
+			gtk_widget_grab_focus (GTK_WIDGET (gedit_tab_get_view (tab)));
 
 			l = g_slist_next (l);
 			jump_to = FALSE;
@@ -217,19 +212,15 @@ load_file_list (GeditWindow         *window,
 
 	while (l != NULL)
 	{
-		gchar *uri;
-
 		g_return_val_if_fail (l->data != NULL, 0);
 
-		// FIXME: pass the GFile to tab when api is there
-		uri = g_file_get_uri (l->data);
-		tab = gedit_window_create_tab_from_uri (window,
-							uri,
-							encoding,
-							line_pos,
-							create,
-							jump_to);
-		g_free (uri);
+		tab = gedit_window_create_tab_from_location (window,
+							     l->data,
+							     encoding,
+							     line_pos,
+							     column_pos,
+							     create,
+							     jump_to);
 
 		if (tab != NULL)
 		{
@@ -273,100 +264,54 @@ load_file_list (GeditWindow         *window,
 	return loaded_files;
 }
 
-
-// FIXME: we should expose API with GFile and just make the uri
-// variants backward compat wrappers
-
-static gint
-load_uri_list (GeditWindow         *window,
-	       const GSList        *uris,
-	       const GeditEncoding *encoding,
-	       gint                 line_pos,
-	       gboolean             create)
-{
-	GSList *files = NULL;
-	const GSList *u;
-	gint ret;
-
-	for (u = uris; u != NULL; u = u->next)
-	{
-		gchar *uri = u->data;
-
-		if (gedit_utils_is_valid_uri (uri))
-			files = g_slist_prepend (files, g_file_new_for_uri (uri));
-		else
-			g_warning ("invalid uri: %s", uri);
-	}
-	files = g_slist_reverse (files);
-
-	ret = load_file_list (window, files, encoding, line_pos, create);
-
-	g_slist_foreach (files, (GFunc) g_object_unref, NULL);
-	g_slist_free (files);
-
-	return ret;
-}
-
 /**
  * gedit_commands_load_uri:
  *
- * Do nothing if URI does not exist
+ * Do nothing if location does not exist
  */
 void
-gedit_commands_load_uri (GeditWindow         *window,
-			 const gchar         *uri,
-			 const GeditEncoding *encoding,
-			 gint                 line_pos)
+gedit_commands_load_location (GeditWindow         *window,
+			      GFile               *location,
+			      const GeditEncoding *encoding,
+			      gint                 line_pos,
+			      gint                 column_pos)
 {
-	GSList *uris = NULL;
+	GSList *locations = NULL;
+	gchar *uri;
 
 	g_return_if_fail (GEDIT_IS_WINDOW (window));
-	g_return_if_fail (uri != NULL);
-	g_return_if_fail (gedit_utils_is_valid_uri (uri));
+	g_return_if_fail (G_IS_FILE (location));
+	g_return_if_fail (gedit_utils_is_valid_location (location));
 
+	uri = g_file_get_uri (location);
 	gedit_debug_message (DEBUG_COMMANDS, "Loading URI '%s'", uri);
+	g_free (uri);
 
-	uris = g_slist_prepend (uris, (gchar *)uri);
+	locations = g_slist_prepend (locations, location);
 
-	load_uri_list (window, uris, encoding, line_pos, FALSE);
+	load_file_list (window, locations, encoding, line_pos, column_pos, FALSE);
 
-	g_slist_free (uris);
+	g_slist_free (locations);
 }
 
 /**
  * gedit_commands_load_uris:
  *
- * Ignore non-existing URIs 
+ * Ignore non-existing locations 
  */
 gint
-gedit_commands_load_uris (GeditWindow         *window,
-			  const GSList        *uris,
-			  const GeditEncoding *encoding,
-			  gint                 line_pos)
+gedit_commands_load_locations (GeditWindow         *window,
+			       const GSList        *locations,
+			       const GeditEncoding *encoding,
+			       gint                 line_pos,
+			       gint                 column_pos)
 {
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), 0);
-	g_return_val_if_fail ((uris != NULL) && (uris->data != NULL), 0);
+	g_return_val_if_fail ((locations != NULL) && (locations->data != NULL), 0);
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	return load_uri_list (window, uris, encoding, line_pos, FALSE);
-}
-
-/*
- * This should become public once we convert all api to GFile:
- */
-static gint
-gedit_commands_load_files (GeditWindow         *window,
-			   GSList              *files,
-			   const GeditEncoding *encoding,
-			   gint                 line_pos)
-{
-	g_return_val_if_fail (GEDIT_IS_WINDOW (window), 0);
-	g_return_val_if_fail ((files != NULL) && (files->data != NULL), 0);
-
-	gedit_debug (DEBUG_COMMANDS);
-
-	return load_file_list (window, files, encoding, line_pos, FALSE);
+	return load_file_list (window, locations, encoding, line_pos, column_pos, FALSE);
 }
 
 /*
@@ -378,11 +323,12 @@ gint
 _gedit_cmd_load_files_from_prompt (GeditWindow         *window,
 				   GSList              *files,
 				   const GeditEncoding *encoding,
-				   gint                 line_pos)
+				   gint                 line_pos,
+				   gint                 column_pos)
 {
 	gedit_debug (DEBUG_COMMANDS);
 
-	return load_file_list (window, files, encoding, line_pos, TRUE);
+	return load_file_list (window, files, encoding, line_pos, column_pos, TRUE);
 }
 
 static void
@@ -423,10 +369,11 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 	/* Remember the folder we navigated to */
 	 _gedit_window_set_default_location (window, files->data);
 
-	gedit_commands_load_files (window,
-				   files,
-				   encoding,
-				   0);
+	gedit_commands_load_locations (window,
+				       files,
+				       encoding,
+				       0,
+				       0);
 
 	g_slist_foreach (files, (GFunc) g_object_unref, NULL);
 	g_slist_free (files);
@@ -482,8 +429,6 @@ _gedit_cmd_file_open (GtkAction   *action,
 		if (file != NULL)
 		{
 			default_path = g_file_get_parent (file);
-			g_return_if_fail (default_path != NULL); /* file cannot be / */
-
 			g_object_unref (file);
 		}
 	}
@@ -607,6 +552,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 	GeditTab *tab;
 	gpointer data;
 	GSList *tabs_to_save_as;
+	GeditDocumentNewlineType newline_type;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -624,6 +570,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 	g_return_if_fail (file != NULL);
 
 	encoding = gedit_file_chooser_dialog_get_encoding (dialog);
+	newline_type = gedit_file_chooser_dialog_get_newline_type (dialog);
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
@@ -631,7 +578,6 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 	{
 		GeditDocument *doc;
 		gchar *parse_name;
-		gchar *uri;
 
 		doc = gedit_tab_get_document (tab);
 		g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
@@ -649,10 +595,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		 * even if the saving fails... */
 		 _gedit_window_set_default_location (window, file);
 
-		// FIXME: pass the GFile to tab when api is there
-		uri = g_file_get_uri (file);
-		_gedit_tab_save_as (tab, uri, encoding);
-		g_free (uri);
+		_gedit_tab_save_as (tab, file, encoding, newline_type);
 	}
 
 	g_object_unref (file);
@@ -741,13 +684,14 @@ file_save_as (GeditTab    *tab,
 	GFile *file;
 	gboolean uri_set = FALSE;
 	const GeditEncoding *encoding;
+	GeditDocumentNewlineType newline_type;
 
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 	g_return_if_fail (GEDIT_IS_WINDOW (window));
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	save_dialog = gedit_file_chooser_dialog_new (_("Save As\342\200\246"),
+	save_dialog = gedit_file_chooser_dialog_new (_("Save As"),
 						     GTK_WINDOW (window),
 						     GTK_FILE_CHOOSER_ACTION_SAVE,
 						     NULL,
@@ -783,7 +727,6 @@ file_save_as (GeditTab    *tab,
 		g_object_unref (file);
 	}
 
-
 	if (!uri_set)
 	{
 		GFile *default_path;
@@ -814,9 +757,14 @@ file_save_as (GeditTab    *tab,
 	encoding = gedit_document_get_encoding (doc);
 	g_return_if_fail (encoding != NULL);
 
+	newline_type = gedit_document_get_newline_type (doc);
+
 	gedit_file_chooser_dialog_set_encoding (GEDIT_FILE_CHOOSER_DIALOG (save_dialog),
 						encoding);
 
+	gedit_file_chooser_dialog_set_newline_type (GEDIT_FILE_CHOOSER_DIALOG (save_dialog),
+	                                            newline_type);
+
 	g_object_set_data (G_OBJECT (save_dialog),
 			   GEDIT_TAB_TO_SAVE_AS,
 			   tab);
@@ -1645,6 +1593,12 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 			g_object_set_data (G_OBJECT (window),
 					   GEDIT_IS_QUITTING,
 					   GBOOLEAN_TO_POINTER (FALSE));
+
+#ifdef OS_OSX
+			g_object_set_data (G_OBJECT (window),
+			                   GEDIT_IS_QUITTING_ALL,
+			                   GINT_TO_POINTER (FALSE));
+#endif
 			break;
 	}
 
@@ -1706,6 +1660,11 @@ _gedit_cmd_file_close_tab (GeditTab    *tab,
 			   GEDIT_IS_QUITTING,
 			   GBOOLEAN_TO_POINTER (FALSE));
 
+	g_object_set_data (G_OBJECT (window), 
+	                   GEDIT_IS_QUITTING_ALL, 
+	                   GINT_TO_POINTER (FALSE));
+
+
 	if (tab_can_close (tab, GTK_WINDOW (window)))
 		gedit_window_close_tab (window, tab);
 }
@@ -1719,8 +1678,15 @@ _gedit_cmd_file_close (GtkAction   *action,
 	gedit_debug (DEBUG_COMMANDS);
 
 	active_tab = gedit_window_get_active_tab (window);
+
 	if (active_tab == NULL)
+	{
+#ifdef OS_OSX
+		/* Close the window on OS X */
+		gtk_widget_destroy (GTK_WIDGET (window));
+#endif
 		return;
+	}
 
 	_gedit_cmd_file_close_tab (active_tab, window);
 }
@@ -1811,12 +1777,50 @@ _gedit_cmd_file_close_all (GtkAction   *action,
 }
 
 /* Quit */
+#ifdef OS_OSX
+static void
+quit_all ()
+{
+	GList *windows;
+	GList *item;
+	GeditApp *app;
+
+	app = gedit_app_get_default ();
+	windows = g_list_copy ((GList *)gedit_app_get_windows (app));
+
+	for (item = windows; item; item = g_list_next (item))
+	{
+		GeditWindow *window = GEDIT_WINDOW (item->data);
+	
+		g_object_set_data (G_OBJECT (window),
+		                   GEDIT_IS_QUITTING_ALL,
+		                   GINT_TO_POINTER (TRUE));
+
+		if (!(gedit_window_get_state (window) &
+		                    (GEDIT_WINDOW_STATE_SAVING |
+		                     GEDIT_WINDOW_STATE_PRINTING |
+		                     GEDIT_WINDOW_STATE_SAVING_SESSION)))
+		{
+			file_close_all (window, TRUE);
+		}
+	}
+}
+#endif
+
 void
 _gedit_cmd_file_quit (GtkAction   *action,
 		     GeditWindow *window)
 {
 	gedit_debug (DEBUG_COMMANDS);
 
+#ifdef OS_OSX
+	if (action != NULL)
+	{
+		quit_all ();
+		return;
+	}
+#endif
+
 	g_return_if_fail (!(gedit_window_get_state (window) &
 	                    (GEDIT_WINDOW_STATE_SAVING |
 	                     GEDIT_WINDOW_STATE_PRINTING |
@@ -1824,3 +1828,4 @@ _gedit_cmd_file_quit (GtkAction   *action,
 
 	file_close_all (window, TRUE);
 }
+/* ex:ts=8:noet: */
