@@ -40,16 +40,18 @@
 G_BEGIN_DECLS
 
 /* Do nothing if URI does not exist */
-void		 gedit_commands_load_uri		(GeditWindow         *window,
-							 const gchar         *uri,
+void		 gedit_commands_load_location		(GeditWindow         *window,
+							 GFile               *location,
 							 const GeditEncoding *encoding,
-							 gint                 line_pos);
+							 gint                 line_pos,
+							 gint                 column_pos);
 
 /* Ignore non-existing URIs */
-gint		 gedit_commands_load_uris		(GeditWindow         *window,
-							 const GSList        *uris,
+gint		 gedit_commands_load_locations		(GeditWindow         *window,
+							 const GSList        *locations,
 							 const GeditEncoding *encoding,
-							 gint                 line_pos);
+							 gint                 line_pos,
+							 gint                 column_pos);
 
 void		 gedit_commands_save_document		(GeditWindow         *window,
                                                          GeditDocument       *document);
@@ -64,7 +66,8 @@ void		 gedit_commands_save_all_documents 	(GeditWindow         *window);
 gint		_gedit_cmd_load_files_from_prompt	(GeditWindow         *window,
 							 GSList              *files,
 							 const GeditEncoding *encoding,
-							 gint                 line_pos);
+							 gint                 line_pos,
+							 gint                 column_pos);
 
 void		_gedit_cmd_file_new			(GtkAction   *action,
 							 GeditWindow *window);
@@ -80,8 +83,6 @@ void		_gedit_cmd_file_revert			(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_file_open_uri		(GtkAction   *action,
 							 GeditWindow *window);
-void		_gedit_cmd_file_page_setup		(GtkAction   *action,
-							 GeditWindow *window);
 void		_gedit_cmd_file_print_preview		(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_file_print			(GtkAction   *action,
@@ -156,6 +157,14 @@ void		_gedit_cmd_file_close_tab 		(GeditTab    *tab,
 void		_gedit_cmd_file_save_documents_list	(GeditWindow *window,
 							 GList       *docs);
 
+
+#if !GTK_CHECK_VERSION (2, 17, 4)
+void		_gedit_cmd_file_page_setup		(GtkAction   *action,
+							 GeditWindow *window);
+#endif
+
+
 G_END_DECLS
 
 #endif /* __GEDIT_COMMANDS_H__ */ 
+/* ex:ts=8:noet: */
