@@ -4,6 +4,7 @@
  *
  * Copyright (C) 2005 - Paolo Maggi
  * Copyright (C) 2007 - Paolo Maggi, Steve Frécinaux
+ * Copyright (C) 2008 - Jesse van den Kieboom
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
  */
  
 /*
- * Modified by the gedit Team, 2005-2007. See the AUTHORS file for a
+ * Modified by the gedit Team, 2005-2008. See the AUTHORS file for a
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
@@ -54,19 +55,12 @@ typedef struct _GeditDocumentLoaderPrivate GeditDocumentLoaderPrivate;
  */
 typedef struct _GeditDocumentLoader GeditDocumentLoader;
 
-struct _GeditDocumentLoader 
+struct _GeditDocumentLoader
 {
 	GObject object;
 
-	GeditDocument		 *document;
-	gboolean		  used;
-
-	/* Info on the current file */
-	GFileInfo		 *info;
-	gchar			 *uri;
-	const GeditEncoding	 *encoding;
-	const GeditEncoding	 *auto_detected_encoding;
-	GeditDocumentNewlineType  auto_detected_newline_type;
+	/*< private > */
+	GeditDocumentLoaderPrivate *priv;
 };
 
 /*
@@ -82,11 +76,6 @@ struct _GeditDocumentLoaderClass
 	void (* loading) (GeditDocumentLoader *loader,
 			  gboolean             completed,
 			  const GError        *error);
-
-	/* VTable */
-	void			(* load)		(GeditDocumentLoader *loader);
-	gboolean		(* cancel)		(GeditDocumentLoader *loader);
-	goffset			(* get_bytes_read)	(GeditDocumentLoader *loader);
 };
 
 /*
@@ -96,7 +85,7 @@ GType 		 	 gedit_document_loader_get_type		(void) G_GNUC_CONST;
 
 /* If enconding == NULL, the encoding will be autodetected */
 GeditDocumentLoader 	*gedit_document_loader_new 		(GeditDocument       *doc,
-								 const gchar         *uri,
+								 GFile               *location,
 								 const GeditEncoding *encoding);
 
 void			 gedit_document_loader_loading		(GeditDocumentLoader *loader,
@@ -113,7 +102,7 @@ GeditDocument		*gedit_document_loader_get_document	(GeditDocumentLoader *loader)
 
 /* Returns STDIN_URI if loading from stdin */
 #define STDIN_URI "stdin:" 
-const gchar		*gedit_document_loader_get_uri		(GeditDocumentLoader *loader);
+GFile			*gedit_document_loader_get_location	(GeditDocumentLoader *loader);
 
 const GeditEncoding	*gedit_document_loader_get_encoding	(GeditDocumentLoader *loader);
 
@@ -128,3 +117,4 @@ GFileInfo		*gedit_document_loader_get_info		(GeditDocumentLoader *loader);
 G_END_DECLS
 
 #endif  /* __GEDIT_DOCUMENT_LOADER_H__  */
+/* ex:ts=8:noet: */
