@@ -48,6 +48,8 @@
 #include "gedit-prefs-manager.h"
 #include <gedit/gedit-encodings-combo-box.h>
 
+#include "gseal-gtk-compat.h"
+
 #if !GTK_CHECK_VERSION (2, 17, 1)
 #include "gedit-message-area.h"
 #endif
@@ -144,7 +146,7 @@ set_message_area_text_and_icon (GtkWidget   *message_area,
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	if (secondary_text != NULL)
@@ -154,7 +156,7 @@ set_message_area_text_and_icon (GtkWidget   *message_area,
 		secondary_label = gtk_label_new (secondary_markup);
 		g_free (secondary_markup);
 		gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-		GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (secondary_label, TRUE);
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -211,7 +213,7 @@ static gboolean
 parse_gio_error (gint          code,
 	         gchar       **error_message, 
 	         gchar       **message_details, 
-	         const gchar  *uri, 
+	         GFile        *location,
 	         const gchar  *uri_for_display)
 {
 	gboolean ret = TRUE;
@@ -230,7 +232,7 @@ parse_gio_error (gint          code,
 			gchar *scheme_string;
 			gchar *scheme_markup;
 			
-			scheme_string = g_uri_parse_scheme (uri);
+			scheme_string = g_file_get_uri_scheme (location);
 
 			if ((scheme_string != NULL) && g_utf8_validate (scheme_string, -1, NULL))
 			{
@@ -280,8 +282,11 @@ parse_gio_error (gint          code,
 		 */
 		{
 			gchar *hn = NULL;
+			gchar *uri;
 
-			if (gedit_utils_decode_uri (uri, NULL, NULL, &hn, NULL, NULL))
+			uri = g_file_get_uri (location);
+
+			if (uri && gedit_utils_decode_uri (uri, NULL, NULL, &hn, NULL, NULL))
 			{
 				if (hn != NULL)
 				{
@@ -304,6 +309,8 @@ parse_gio_error (gint          code,
 					g_free (host_markup);
 				}
 			}
+
+			g_free (uri);
 			
 			if (!*message_details)
 			{
@@ -337,7 +344,7 @@ static gboolean
 parse_gedit_error (gint          code,
 	           gchar       **error_message, 
 	           gchar       **message_details, 
-	           const gchar  *uri, 
+	           GFile        *location,
 	           const gchar  *uri_for_display)
 {
 	gboolean ret = TRUE;
@@ -360,7 +367,7 @@ static void
 parse_error (const GError *error, 
 	     gchar       **error_message, 
 	     gchar       **message_details, 
-	     const gchar  *uri, 
+	     GFile        *location,
 	     const gchar  *uri_for_display)
 {
 	gboolean ret = FALSE;
@@ -370,7 +377,7 @@ parse_error (const GError *error,
 		ret = parse_gio_error (error->code,
 				       error_message,
 				       message_details,
-				       uri,
+				       location,
 				       uri_for_display);
 	}
 	else if (error->domain == GEDIT_DOCUMENT_ERROR)
@@ -378,21 +385,21 @@ parse_error (const GError *error,
 		ret = parse_gedit_error (error->code,
 					 error_message,
 					 message_details,
-					 uri,
+					 location,
 					 uri_for_display);
 	}
 	
 	if (!ret)
 	{
 		g_warning ("Hit unhandled case %d (%s) in %s.", 
-			   error->code, error->message, G_STRFUNC);	
+			   error->code, error->message, G_STRFUNC);
 		*message_details = g_strdup_printf (_("Unexpected error: %s"), 
-						   error->message);
+						    error->message);
 	}
 }
 
 GtkWidget *
-gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
+gedit_unrecoverable_reverting_error_message_area_new (GFile        *location,
 						      const GError *error)
 {
 	gchar *error_message = NULL;
@@ -402,12 +409,12 @@ gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
 	gchar *temp_uri_for_display;
 	GtkWidget *message_area;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail ((error->domain == GEDIT_DOCUMENT_ERROR) || 
 			      (error->domain == G_IO_ERROR), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -427,7 +434,7 @@ gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
 	}
 	else
 	{
-		parse_error (error, &error_message, &message_details, uri, uri_for_display);
+		parse_error (error, &error_message, &message_details, location, uri_for_display);
 	}
 
 	if (error_message == NULL)
@@ -570,7 +577,7 @@ create_conversion_error_message_area (const gchar *primary_text,
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	if (secondary_text != NULL)
@@ -580,7 +587,7 @@ create_conversion_error_message_area (const gchar *primary_text,
 		secondary_label = gtk_label_new (secondary_markup);
 		g_free (secondary_markup);
 		gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-		GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (secondary_label, TRUE);
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -595,7 +602,7 @@ create_conversion_error_message_area (const gchar *primary_text,
 }
 
 GtkWidget *
-gedit_io_loading_error_message_area_new (const gchar         *uri,
+gedit_io_loading_error_message_area_new (GFile               *location,
 					 const GeditEncoding *encoding,
 					 const GError        *error)
 {
@@ -609,13 +616,13 @@ gedit_io_loading_error_message_area_new (const gchar         *uri,
 	gboolean edit_anyway = FALSE;
 	gboolean convert_error = FALSE;
 	
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail ((error->domain == G_CONVERT_ERROR) ||
 			      (error->domain == GEDIT_DOCUMENT_ERROR) ||
 			      (error->domain == G_IO_ERROR), NULL);
 	
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -675,7 +682,7 @@ gedit_io_loading_error_message_area_new (const gchar         *uri,
 	}
 	else
 	{
-		parse_error (error, &error_message, &message_details, uri, uri_for_display);
+		parse_error (error, &error_message, &message_details, location, uri_for_display);
 	}
 
 	if (error_message == NULL)
@@ -707,9 +714,9 @@ gedit_io_loading_error_message_area_new (const gchar         *uri,
 
 GtkWidget *
 gedit_conversion_error_while_saving_message_area_new (
-						const gchar         *uri,
+						GFile               *location,
 						const GeditEncoding *encoding,
-				    		const GError        *error)
+						const GError        *error)
 {
 	gchar *error_message = NULL;
 	gchar *message_details = NULL;
@@ -719,19 +726,20 @@ gedit_conversion_error_while_saving_message_area_new (
 	gchar *temp_uri_for_display;
 	GtkWidget *message_area;
 	
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
-	g_return_val_if_fail (error->domain == G_CONVERT_ERROR, NULL);
+	g_return_val_if_fail (error->domain == G_CONVERT_ERROR ||
+	                      error->domain == G_IO_ERROR, NULL);
 	g_return_val_if_fail (encoding != NULL, NULL);
 	
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 	
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -779,7 +787,7 @@ gedit_conversion_error_message_area_get_encoding (GtkWidget *message_area)
 }
 
 GtkWidget *
-gedit_file_already_open_warning_message_area_new (const gchar *uri)
+gedit_file_already_open_warning_message_area_new (GFile *location)
 {
 	GtkWidget *message_area;
 	GtkWidget *hbox_content;
@@ -794,15 +802,17 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 	gchar *full_formatted_uri;
 	gchar *uri_for_display;
 	gchar *temp_uri_for_display;
-	
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
+
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 	
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -852,7 +862,7 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	secondary_text = _("gedit opened this instance of the file in a non-editable way. "
@@ -862,7 +872,7 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 	secondary_label = gtk_label_new (secondary_markup);
 	g_free (secondary_markup);
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (secondary_label, TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -876,7 +886,7 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 
 GtkWidget *
 gedit_externally_modified_saving_error_message_area_new (
-						const gchar  *uri,
+						GFile        *location,
 						const GError *error)
 {
 	GtkWidget *message_area;
@@ -893,19 +903,19 @@ gedit_externally_modified_saving_error_message_area_new (
 	gchar *uri_for_display;
 	gchar *temp_uri_for_display;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail (error->domain == GEDIT_DOCUMENT_ERROR, NULL);
 	g_return_val_if_fail (error->code == GEDIT_DOCUMENT_ERROR_EXTERNALLY_MODIFIED, NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -958,7 +968,7 @@ gedit_externally_modified_saving_error_message_area_new (
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	secondary_text = _("If you save it, all the external changes could be lost. Save it anyway?");
@@ -967,7 +977,7 @@ gedit_externally_modified_saving_error_message_area_new (
 	secondary_label = gtk_label_new (secondary_markup);
 	g_free (secondary_markup);
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (secondary_label, TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -980,7 +990,7 @@ gedit_externally_modified_saving_error_message_area_new (
 }
 
 GtkWidget *
-gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
+gedit_no_backup_saving_error_message_area_new (GFile        *location,
 					       const GError *error)
 {
 	GtkWidget *message_area;
@@ -997,21 +1007,21 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 	gchar *uri_for_display;
 	gchar *temp_uri_for_display;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail (((error->domain == GEDIT_DOCUMENT_ERROR &&
 			        error->code == GEDIT_DOCUMENT_ERROR_CANT_CREATE_BACKUP) ||
 			       (error->domain == G_IO_ERROR &&
 			        error->code == G_IO_ERROR_CANT_CREATE_BACKUP)), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -1068,7 +1078,7 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	secondary_text = _("gedit could not back up the old copy of the file before saving the new one. "
@@ -1079,7 +1089,7 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 	secondary_label = gtk_label_new (secondary_markup);
 	g_free (secondary_markup);
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (secondary_label, TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -1092,7 +1102,7 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 }
 
 GtkWidget *
-gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
+gedit_unrecoverable_saving_error_message_area_new (GFile        *location,
 						   const GError *error)
 {
 	gchar *error_message = NULL;
@@ -1104,12 +1114,12 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 	gchar *temp_uri_for_display;
 	GtkWidget *message_area;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail ((error->domain == GEDIT_DOCUMENT_ERROR) || 
 			      (error->domain == G_IO_ERROR), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -1124,7 +1134,7 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 
 	if (is_gio_error (error, G_IO_ERROR_NOT_SUPPORTED))
 	{
-		scheme_string = g_uri_parse_scheme (uri);
+		scheme_string = g_file_get_uri_scheme (location);
 
 		if ((scheme_string != NULL) && g_utf8_validate (scheme_string, -1, NULL))
 		{
@@ -1193,7 +1203,7 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 		parse_error (error, 
 			     &error_message, 
 			     &message_details, 
-			     uri, 
+			     location,
 			     uri_for_display);
 	}
 
@@ -1215,8 +1225,8 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 }
 
 GtkWidget *
-gedit_externally_modified_message_area_new (const gchar *uri,
-					    gboolean     document_modified)
+gedit_externally_modified_message_area_new (GFile   *location,
+					    gboolean document_modified)
 {
 	gchar *full_formatted_uri;
 	gchar *uri_for_display;
@@ -1225,9 +1235,9 @@ gedit_externally_modified_message_area_new (const gchar *uri,
 	const gchar *secondary_text;
 	GtkWidget *message_area;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -1285,3 +1295,4 @@ gedit_externally_modified_message_area_new (const gchar *uri,
 	return message_area;
 }
 
+/* ex:ts=8:noet: */
