@@ -42,6 +42,8 @@
 #include "gedit-debug.h"
 #include "gedit-plugin.h"
 
+#define GEDIT_PLUGIN_IAGE 3
+
 void
 _gedit_plugin_info_ref (GeditPluginInfo *info)
 {
@@ -77,6 +79,7 @@ _gedit_plugin_info_unref (GeditPluginInfo *info)
 	g_free (info->website);
 	g_free (info->copyright);
 	g_free (info->loader);
+	g_free (info->version);
 	g_strfreev (info->authors);
 
 	g_free (info);
@@ -144,11 +147,11 @@ _gedit_plugin_info_new (const gchar *file)
 		goto error;
 	}
 	
-	/* Check IAge=2 */
+	/* Check IAge=GEDIT_PLUGIN_IAGE */
 	if (g_key_file_get_integer (plugin_file,
 				    "Gedit Plugin",
 				    "IAge",
-				    NULL) != 2)
+				    NULL) != GEDIT_PLUGIN_IAGE)
 	{
 		gedit_debug_message (DEBUG_PLUGINS,
 				     "Wrong IAge in file: %s", file);
@@ -262,7 +265,17 @@ _gedit_plugin_info_new (const gchar *file)
 		info->website = str;
 	else
 		gedit_debug_message (DEBUG_PLUGINS, "Could not find 'Website' in %s", file);
-		
+	
+	/* Get Version */
+	str = g_key_file_get_string (plugin_file,
+				     "Gedit Plugin",
+				     "Version",
+				     NULL);
+	if (str)
+		info->version = str;
+	else
+		gedit_debug_message (DEBUG_PLUGINS, "Could not find 'Version' in %s", file);
+	
 	g_key_file_free (plugin_file);
 	
 	/* If we know nothing about the availability of the plugin,
@@ -373,3 +386,12 @@ gedit_plugin_info_get_copyright (GeditPluginInfo *info)
 
 	return info->copyright;
 }
+
+const gchar *
+gedit_plugin_info_get_version (GeditPluginInfo *info)
+{
+	g_return_val_if_fail (info != NULL, NULL);
+
+	return info->version;
+}
+/* ex:ts=8:noet: */
