@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-prefs-manager-app.h,v 1.4 2006/09/23 14:37:09 pborelli Exp $
+ * $Id$
  *
  */
 
@@ -75,5 +75,11 @@ gint		 gedit_prefs_manager_get_bottom_panel_active_page (void);
 void 		 gedit_prefs_manager_set_bottom_panel_active_page (gint id);
 gboolean	 gedit_prefs_manager_bottom_panel_active_page_can_set (void);
 
+/* File filter */
+gint		 gedit_prefs_manager_get_active_file_filter	(void);
+void 		 gedit_prefs_manager_set_active_file_filter	(gint id);
+gboolean	 gedit_prefs_manager_active_file_filter_can_set	(void);
+
 
 #endif /* __GEDIT_PREFS_MANAGER_APP_H__ */
+/* ex:ts=8:noet: */
