@@ -516,7 +516,7 @@ create_compositor (GeditPrintJob *job)
 						     "tab-width", gtk_source_view_get_tab_width (GTK_SOURCE_VIEW (job->priv->view)),
 						     "highlight-syntax", gtk_source_buffer_get_highlight_syntax (GTK_SOURCE_BUFFER (job->priv->doc)) &&
 					   				 gedit_prefs_manager_get_print_syntax_hl (),
-						     "wrap-mode", gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (job->priv->view)),
+						     "wrap-mode", gedit_prefs_manager_get_print_wrap_mode (),
 						     "print-line-numbers", gedit_prefs_manager_get_print_line_numbers (),
 						     "print-header", gedit_prefs_manager_get_print_header (),
 						     "print-footer", FALSE,
@@ -524,7 +524,7 @@ create_compositor (GeditPrintJob *job)
 						     "line-numbers-font-name", print_font_numbers,
 						     "header-font-name", print_font_header,
 						     NULL));
-	
+
 	g_free (print_font_body);
 	g_free (print_font_header);
 	g_free (print_font_numbers);
@@ -856,3 +856,11 @@ gedit_print_job_get_print_settings (GeditPrintJob *job)
 	return gtk_print_operation_get_print_settings (job->priv->operation);
 }
 
+GtkPageSetup *
+gedit_print_job_get_page_setup (GeditPrintJob *job)
+{
+	g_return_val_if_fail (GEDIT_IS_PRINT_JOB (job), NULL);
+
+	return gtk_print_operation_get_default_page_setup (job->priv->operation);
+}
+/* ex:ts=8:noet: */
