@@ -40,6 +40,7 @@
 #include <cairo-pdf.h>
 
 #include "gedit-print-preview.h"
+#include "gseal-gtk-compat.h"
 
 #define PRINTER_DPI (72.)
 
@@ -612,6 +613,7 @@ create_bar (GeditPrintPreview *preview)
 
 	/* We are displaying 'XXX of XXX'. */
 	gtk_box_pack_start (GTK_BOX (status),
+	                    /* Translators: the "of" from "1 of 19" in print preview. */
 			    gtk_label_new (_("of")),
 			    FALSE, FALSE, 0);
 
@@ -955,7 +957,7 @@ create_preview_layout (GeditPrintPreview *preview)
 			       GDK_BUTTON_PRESS_MASK |
 			       GDK_KEY_PRESS_MASK);
 
-	GTK_WIDGET_SET_FLAGS (priv->layout, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (priv->layout, TRUE);
 
   	g_signal_connect (priv->layout,
 			  "key-press-event",
@@ -1324,3 +1326,4 @@ gedit_print_preview_new (GtkPrintOperation        *op,
 	return GTK_WIDGET (preview);
 }
 
+/* ex:ts=8:noet: */
