@@ -38,10 +38,11 @@
 
 G_BEGIN_DECLS
 
-void		gedit_session_init 		(const char *argv0);
+void		gedit_session_init 		(void);
 gboolean	gedit_session_is_restored 	(void);
 gboolean 	gedit_session_load 		(void);
 
 G_END_DECLS
 
 #endif /* __GEDIT_SESSION_H__ */
+/* ex:ts=8:noet: */
