@@ -121,29 +121,33 @@ void		 gedit_tab_set_auto_save_interval
 						(GeditTab            *tab, 
 						 gint                interval);
 
+void		 gedit_tab_set_info_bar		(GeditTab            *tab,
+						 GtkWidget           *info_bar);
 /*
  * Non exported methods
  */
 GtkWidget 	*_gedit_tab_new 		(void);
 
 /* Whether create is TRUE, creates a new empty document if location does 
-   not refer to an existing file */
-GtkWidget	*_gedit_tab_new_from_uri	(const gchar         *uri,
+   not refer to an existing location */
+GtkWidget	*_gedit_tab_new_from_location	(GFile               *location,
 						 const GeditEncoding *encoding,
 						 gint                 line_pos,
+						 gint                 column_pos,
 						 gboolean             create);
 gchar 		*_gedit_tab_get_name		(GeditTab            *tab);
 gchar 		*_gedit_tab_get_tooltips	(GeditTab            *tab);
 GdkPixbuf 	*_gedit_tab_get_icon		(GeditTab            *tab);
 void		 _gedit_tab_load		(GeditTab            *tab,
-						 const gchar         *uri,
+						 GFile               *location,
 						 const GeditEncoding *encoding,
 						 gint                 line_pos,
+						 gint                 column_pos,
 						 gboolean             create);
 void		 _gedit_tab_revert		(GeditTab            *tab);
 void		 _gedit_tab_save		(GeditTab            *tab);
 void		 _gedit_tab_save_as		(GeditTab            *tab,
-						 const gchar         *uri,
+						 GFile               *location,
 						 const GeditEncoding *encoding,
 						 GeditDocumentNewlineType newline_type);
 
@@ -161,3 +165,4 @@ void		 _gedit_tab_page_setup		(GeditTab            *tab);
 G_END_DECLS
 
 #endif  /* __GEDIT_TAB_H__  */
+/* ex:ts=8:noet: */
