@@ -59,51 +59,15 @@
 #include <X11/Xatom.h>
 #endif
 
+#include "gseal-gtk-compat.h"
+
 #define STDIN_DELAY_MICROSECONDS 100000
 
-/* Returns true if uri is a file: uri and is not a chained uri */
+/* Returns true if location is a file: uri and is not a chained uri */
 gboolean
-gedit_utils_uri_has_file_scheme (const gchar *uri)
+gedit_utils_location_has_file_scheme (GFile *location)
 {
-	GFile *gfile;
-	gboolean res;
-
-	gfile = g_file_new_for_uri (uri);
-	res = g_file_has_uri_scheme (gfile, "file");
-	
-	g_object_unref (gfile);
-	return res;
-}
-
-/* FIXME: we should check for chained URIs */
-gboolean
-gedit_utils_uri_has_writable_scheme (const gchar *uri)
-{
-	GFile *gfile;
-	gchar *scheme;
-	GSList *writable_schemes;
-	gboolean res;
-
-	gfile = g_file_new_for_uri (uri);
-	scheme = g_file_get_uri_scheme (gfile);
-
-	g_return_val_if_fail (scheme != NULL, FALSE);
-
-	g_object_unref (gfile);
-
-	writable_schemes = gedit_prefs_manager_get_writable_vfs_schemes ();
-
-	/* CHECK: should we use g_ascii_strcasecmp? - Paolo (Nov 6, 2005) */
-	res = (g_slist_find_custom (writable_schemes,
-				    scheme,
-				    (GCompareFunc)strcmp) != NULL);
-
-	g_slist_foreach (writable_schemes, (GFunc)g_free, NULL);
-	g_slist_free (writable_schemes);
-
-	g_free (scheme);
-
-	return res;
+	return g_file_has_uri_scheme (location, "file");
 }
 
 static void
@@ -125,22 +89,25 @@ gedit_utils_menu_position_under_widget (GtkMenu  *menu,
 {
 	GtkWidget *widget;
 	GtkRequisition requisition;
+	GtkAllocation allocation;
 
 	widget = GTK_WIDGET (user_data);
 	widget_get_origin (widget, x, y);
 
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
+	gtk_widget_get_allocation (widget, &allocation);
+
 	if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 	{
-		*x += widget->allocation.x + widget->allocation.width - requisition.width;
+		*x += allocation.x + allocation.width - requisition.width;
 	}
 	else
 	{
-		*x += widget->allocation.x;
+		*x += allocation.x;
 	}
 
-	*y += widget->allocation.y + widget->allocation.height;
+	*y += allocation.y + allocation.height;
 
 	*push_in = TRUE;
 }
@@ -234,7 +201,7 @@ gedit_dialog_add_button (GtkDialog   *dialog,
 	button = gedit_gtk_button_new_with_stock_icon (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 
 	gtk_widget_show (button);
 
@@ -344,19 +311,18 @@ gedit_utils_set_atk_relation (GtkWidget *obj1,
 }
 
 gboolean
-gedit_utils_uri_exists (const gchar* text_uri)
+gedit_utils_location_exists (GFile *location)
 {
-	GFile *gfile;
 	gboolean res;
+	gchar *uri;
 		
-	g_return_val_if_fail (text_uri != NULL, FALSE);
-	
-	gedit_debug_message (DEBUG_UTILS, "text_uri: %s", text_uri);
+	g_return_val_if_fail (G_IS_FILE (location), FALSE);
 
-	gfile = g_file_new_for_uri (text_uri);
-	res = g_file_query_exists (gfile, NULL);
+	uri = g_file_get_uri (location);
+	gedit_debug_message (DEBUG_UTILS, "text_uri: %s", uri);
+	g_free (uri);
 
-	g_object_unref (gfile);
+	res = g_file_query_exists (location, NULL);
 
 	gedit_debug_message (DEBUG_UTILS, res ? "TRUE" : "FALSE");
 
@@ -900,7 +866,7 @@ gedit_utils_get_window_workspace (GtkWindow *gtkwindow)
 	guint ret = GEDIT_ALL_WORKSPACES;
 
 	g_return_val_if_fail (GTK_IS_WINDOW (gtkwindow), 0);
-	g_return_val_if_fail (GTK_WIDGET_REALIZED (GTK_WIDGET (gtkwindow)), 0);
+	g_return_val_if_fail (gtk_widget_get_realized (GTK_WIDGET (gtkwindow)), 0);
 
 	window = gtk_widget_get_window (GTK_WIDGET (gtkwindow));
 	display = gdk_drawable_get_display (window);
@@ -1019,15 +985,24 @@ has_valid_scheme (const gchar *uri)
 }
 
 gboolean
-gedit_utils_is_valid_uri (const gchar *uri)
+gedit_utils_is_valid_location (GFile *location)
 {
 	const guchar *p;
+	gchar *uri;
+	gboolean is_valid;
 
-	if (uri == NULL)
+	if (location == NULL)
 		return FALSE;
 
+	uri = g_file_get_uri (location);
+
 	if (!has_valid_scheme (uri))
+	{
+		g_free (uri);
 		return FALSE;
+	}
+
+	is_valid = TRUE;
 
 	/* We expect to have a fully valid set of characters */
 	for (p = (const guchar *)uri; *p; p++) {
@@ -1035,20 +1010,31 @@ gedit_utils_is_valid_uri (const gchar *uri)
 		{
 			++p;
 			if (!g_ascii_isxdigit (*p))
-				return FALSE;
+			{
+				is_valid = FALSE;
+				break;
+			}
 
 			++p;		
 			if (!g_ascii_isxdigit (*p))
-				return FALSE;
+			{
+				is_valid = FALSE;
+				break;
+			}
 		}
 		else
 		{
 			if (*p <= 32 || *p >= 128)
-				return FALSE;
+			{
+				is_valid = FALSE;
+				break;
+			}
 		}
 	}
 
-	return TRUE;
+	g_free (uri);
+
+	return is_valid;
 }
 
 static GtkWidget *
@@ -1214,13 +1200,15 @@ gedit_utils_make_canonical_uri_from_shell_arg (const gchar *str)
 	 */
 
 	gfile = g_file_new_for_commandline_arg (str);
-	uri = g_file_get_uri (gfile);
-	g_object_unref (gfile);
 
-	if (gedit_utils_is_valid_uri (uri))
+	if (gedit_utils_is_valid_location (gfile))
+	{
+		uri = g_file_get_uri (gfile);
+		g_object_unref (gfile);
 		return uri;
+	}
 	
-	g_free (uri);
+	g_object_unref (gfile);
 	return NULL;
 }
 
@@ -1248,26 +1236,26 @@ gedit_utils_file_has_parent (GFile *gfile)
 
 /**
  * gedit_utils_basename_for_display:
- * @uri: uri for which the basename should be displayed
+ * @location: location for which the basename should be displayed
  *
  * Return the basename of a file suitable for display to users.
  */
 gchar *
-gedit_utils_basename_for_display (gchar const *uri)
+gedit_utils_basename_for_display (GFile *location)
 {
 	gchar *name;
-	GFile *gfile;
 	gchar *hn;
+	gchar *uri;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 
-	gfile = g_file_new_for_uri (uri);
+	uri = g_file_get_uri (location);
 
 	/* First, try to query the display name, but only on local files */
-	if (g_file_has_uri_scheme (gfile, "file"))
+	if (gedit_utils_location_has_file_scheme (location))
 	{
 		GFileInfo *info;
-		info = g_file_query_info (gfile,
+		info = g_file_query_info (location,
 					  G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME, 
 					  G_FILE_QUERY_INFO_NONE, 
 					  NULL, 
@@ -1285,12 +1273,12 @@ gedit_utils_basename_for_display (gchar const *uri)
 			 * g_filename_display_basename on the local path */
 			gchar *local_path;
 		
-			local_path = g_file_get_path (gfile);
+			local_path = g_file_get_path (location);
 			name = g_filename_display_basename (local_path);
 			g_free (local_path);
 		}
 	}
-	else if (gedit_utils_file_has_parent (gfile) || !gedit_utils_decode_uri (uri, NULL, NULL, &hn, NULL, NULL))
+	else if (gedit_utils_file_has_parent (location) || !gedit_utils_decode_uri (uri, NULL, NULL, &hn, NULL, NULL))
 	{
 		/* For remote files with a parent (so not just http://foo.com)
 		   or remote file for which the decoding of the host name fails,
@@ -1298,7 +1286,7 @@ gedit_utils_basename_for_display (gchar const *uri)
 		gchar *parse_name;
 		gchar *base;
 
-		parse_name = g_file_get_parse_name (gfile);
+		parse_name = g_file_get_parse_name (location);
 		base = g_filename_display_basename (parse_name);
 		name = g_uri_unescape_string (base, NULL);
 		
@@ -1323,14 +1311,14 @@ gedit_utils_basename_for_display (gchar const *uri)
 		g_free (hn);
 	}
 
-	g_object_unref (gfile);
+	g_free (uri);
 
 	return name;
 }
 
 /**
  * gedit_utils_uri_for_display:
- * @uri: uri to be displayed.
+ * @location: location to be displayed.
  *
  * Filter, modify, unescape and change @uri to make it appropriate
  * for display to users.
@@ -1340,16 +1328,9 @@ gedit_utils_basename_for_display (gchar const *uri)
  * Return value: a string which represents @uri and can be displayed.
  */
 gchar *
-gedit_utils_uri_for_display (const gchar *uri)
+gedit_utils_uri_for_display (GFile *location)
 {
-	GFile *gfile;
-	gchar *parse_name;
-
-	gfile = g_file_new_for_uri (uri);
-	parse_name = g_file_get_parse_name (gfile);
-	g_object_unref (gfile);
-
-	return parse_name;
+	return g_file_get_parse_name (location);
 }
 
 /**
@@ -1544,3 +1525,4 @@ gedit_utils_decode_uri (const gchar *uri,
 	
 	return TRUE;
 }
+/* ex:ts=8:noet: */
