@@ -105,10 +105,11 @@ GType 		 gedit_window_get_type 			(void) G_GNUC_CONST;
 GeditTab	*gedit_window_create_tab		(GeditWindow         *window,
 							 gboolean             jump_to);
 							 
-GeditTab	*gedit_window_create_tab_from_uri	(GeditWindow         *window,
-							 const gchar         *uri,
+GeditTab	*gedit_window_create_tab_from_location	(GeditWindow         *window,
+							 GFile               *location,
 							 const GeditEncoding *encoding,
 							 gint                 line_pos,
+							 gint                 column_pos,
 							 gboolean             create,
 							 gboolean             jump_to);
 							 
@@ -154,9 +155,6 @@ GeditWindowState gedit_window_get_state 		(GeditWindow         *window);
 GeditTab        *gedit_window_get_tab_from_location	(GeditWindow         *window,
 							 GFile               *location);
 
-GeditTab        *gedit_window_get_tab_from_uri		(GeditWindow         *window,
-							 const gchar         *uri);
-
 /* Message bus */
 GeditMessageBus	*gedit_window_get_message_bus		(GeditWindow         *window);
 
@@ -185,13 +183,12 @@ gboolean	 _gedit_window_is_fullscreen		(GeditWindow         *window);
 
 /* these are in gedit-window because of screen safety */
 void		 _gedit_recent_add			(GeditWindow	     *window,
-							 const gchar         *uri,
+							 GFile               *location,
 							 const gchar         *mime);
 void		 _gedit_recent_remove			(GeditWindow         *window,
-							 const gchar         *uri);
-
-GtkWidget 	*_gedit_window_get_menu_bar		(GeditWindow         *window);
+							 GFile               *location);
 
 G_END_DECLS
 
 #endif  /* __GEDIT_WINDOW_H__  */
+/* ex:ts=8:noet: */
