@@ -59,6 +59,8 @@
 #include "eggsmclient.h"
 #include "eggdesktopfile.h"
 
+#include "gseal-gtk-compat.h"
+
 #ifdef G_OS_WIN32
 #define SAVE_DATADIR DATADIR
 #undef DATADIR
@@ -66,7 +68,6 @@
 #include <conio.h>
 #define _WIN32_WINNT 0x0500
 #include <windows.h>
-#include "gedit-metadata-manager.h"
 #define DATADIR SAVE_DATADIR
 #undef SAVE_DATADIR
 #endif
@@ -77,6 +78,10 @@
 #include "osx/gedit-osx.h"
 #endif
 
+#ifndef ENABLE_GVFS_METADATA
+#include "gedit-metadata-manager.h"
+#endif
+
 static guint32 startup_timestamp = 0;
 
 #ifndef G_OS_WIN32
@@ -87,6 +92,7 @@ static BaconMessageConnection *connection;
 
 /* command line */
 static gint line_position = 0;
+static gint column_position = 0;
 static gchar *encoding_charset = NULL;
 static gboolean new_window_option = FALSE;
 static gboolean new_document_option = FALSE;
@@ -135,7 +141,7 @@ static const GOptionEntry options [] =
 	  N_("Create a new document in an existing instance of gedit"), NULL },
 
 	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &remaining_args,
-	  NULL, N_("[FILE...]") }, /* collects file arguments */
+	  NULL, N_("[FILE...] [+LINE[:COLUMN]]") }, /* collects file arguments */
 
 	{NULL}
 };
@@ -156,6 +162,26 @@ free_command_line_data (void)
 	new_window_option = FALSE;
 	new_document_option = FALSE;
 	line_position = 0;
+	column_position = 0;
+}
+
+static void
+get_line_column_position (const gchar *arg)
+{
+	gchar **split;
+
+	split = g_strsplit (arg, ":", 2);
+
+	if (split != NULL)
+	{
+		if (split[0] != NULL)
+			line_position = atoi (split[0]);
+
+		if (split[1] != NULL)
+			column_position = atoi (split[1]);
+	}
+
+	g_strfreev (split);
 }
 
 static void
@@ -170,10 +196,13 @@ gedit_get_command_line_data (void)
 			if (*remaining_args[i] == '+')
 			{
 				if (*(remaining_args[i] + 1) == '\0')
+				{
 					/* goto the last line of the document */
 					line_position = G_MAXINT;
+					column_position = 0;
+				}
 				else
-					line_position = atoi (remaining_args[i] + 1);
+					get_line_column_position (remaining_args[i] + 1);
 			}
 			else
 			{
@@ -319,7 +348,7 @@ on_message_received (const char *message,
 			gint n_uris, j;
 			gchar **uris;
 
-			line_position = atoi (params[1]);
+			get_line_column_position (params[1]);
 
 			if (params[2] != '\0')
 				encoding = gedit_encoding_get_from_charset (params[2]);
@@ -372,7 +401,8 @@ on_message_received (const char *message,
 		_gedit_cmd_load_files_from_prompt (window,
 						   file_list,
 						   encoding,
-						   line_position);
+						   line_position,
+						   column_position);
 
 		if (new_document_option)
 			gedit_window_create_tab (window, TRUE);
@@ -394,7 +424,7 @@ on_message_received (const char *message,
 	 * terminal. We also need to make sure that the window
 	 * has been realized otherwise it will not work. lame.
 	 */
-	if (!GTK_WIDGET_REALIZED (window))
+	if (!gtk_widget_get_realized (GTK_WIDGET (window)))
 		gtk_widget_realize (GTK_WIDGET (window));
 
 #ifdef GDK_WINDOWING_X11
@@ -485,8 +515,8 @@ send_bacon_message (void)
 		command = g_string_append (command, "OPEN-URIS");
 
 		g_string_append_printf (command,
-					"\t%d\t%s\t%u\t",
-					line_position,
+					"\t%d:%d\t%s\t%u\t",
+					line_position, column_position,
 					encoding_charset ? encoding_charset : "",
 					g_slist_length (file_list));
 
@@ -722,7 +752,8 @@ main (int argc, char *argv[])
 			_gedit_cmd_load_files_from_prompt (window, 
 							   file_list, 
 							   encoding, 
-							   line_position);
+							   line_position,
+							   column_position);
 		}
 		else
 		{
@@ -753,10 +784,11 @@ main (int argc, char *argv[])
 	g_object_unref (engine);
 	gedit_prefs_manager_app_shutdown ();
 
-#ifdef G_OS_WIN32
+#ifndef ENABLE_GVFS_METADATA
 	gedit_metadata_manager_shutdown ();
 #endif
 
 	return 0;
 }
 
+/* ex:ts=8:noet: */
