@@ -37,6 +37,7 @@
 typedef struct
 {
 	gulong tab_added_handler_id;
+	gulong tab_removed_handler_id;
 } WindowData;
 
 typedef struct
@@ -155,10 +156,17 @@ disconnect_handlers (GeditView *view)
 
 	data = g_object_steal_data (G_OBJECT (doc), DOCUMENT_DATA_KEY);
 
-	g_signal_handler_disconnect (doc, data->document_loaded_handler_id);
-	g_signal_handler_disconnect (doc, data->document_saved_handler_id);
+	if (data)
+	{
+		g_signal_handler_disconnect (doc, data->document_loaded_handler_id);
+		g_signal_handler_disconnect (doc, data->document_saved_handler_id);
 
-	document_data_free (data);
+		document_data_free (data);
+	}
+	else
+	{
+		g_warning ("Modeline handlers not found");
+	}
 }
 
 static void
@@ -169,6 +177,14 @@ on_window_tab_added (GeditWindow *window,
 	connect_handlers (gedit_tab_get_view (tab));
 }
 
+static void
+on_window_tab_removed (GeditWindow *window,
+		       GeditTab *tab,
+		       gpointer user_data)
+{
+	disconnect_handlers (gedit_tab_get_view (tab));
+}
+
 static void
 gedit_modeline_plugin_activate (GeditPlugin *plugin,
 				GeditWindow *window)
@@ -188,10 +204,15 @@ gedit_modeline_plugin_activate (GeditPlugin *plugin,
 	g_list_free (views);
 
 	wdata = g_slice_new (WindowData);
+
 	wdata->tab_added_handler_id =
 		g_signal_connect (window, "tab-added",
 				  G_CALLBACK (on_window_tab_added), NULL);
 
+	wdata->tab_removed_handler_id =
+		g_signal_connect (window, "tab-removed",
+				  G_CALLBACK (on_window_tab_removed), NULL);
+
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY,
 				wdata, (GDestroyNotify) window_data_free);
 }
@@ -207,12 +228,22 @@ gedit_modeline_plugin_deactivate (GeditPlugin *plugin,
 	gedit_debug (DEBUG_PLUGINS);
 
 	wdata = g_object_steal_data (G_OBJECT (window), WINDOW_DATA_KEY);
+
 	g_signal_handler_disconnect (window, wdata->tab_added_handler_id);
+	g_signal_handler_disconnect (window, wdata->tab_removed_handler_id);
+
 	window_data_free (wdata);
 
 	views = gedit_window_get_views (window);
+
 	for (l = views; l != NULL; l = l->next)
+	{
 		disconnect_handlers (GEDIT_VIEW (l->data));
+		
+		modeline_parser_deactivate (GTK_SOURCE_VIEW (l->data));
+	}
+	
 	g_list_free (views);
 }
 
+/* ex:ts=8:noet: */
