@@ -33,6 +33,7 @@ from Library import *
 from Importer import *
 from Exporter import *
 from Document import Document
+from LanguageManager import get_language_manager
 
 class Manager:
         NAME_COLUMN = 0
@@ -46,15 +47,16 @@ class Manager:
         dragging = False
         dnd_target_list = [('text/uri-list', 0, TARGET_URI)]
 
-        def __init__(self):
+        def __init__(self, datadir):
+                self.datadir = datadir
                 self.snippet = None
                 self.dlg = None
                 self._temp_export = None
                 self.snippets_doc = None
                 self.manager = None
+                self.default_size = None
 
                 self.key_press_id = 0
-                self.tooltips = gtk.Tooltips()
                 self.run()
         
         def get_language_snippets(self, path, name = None):
@@ -113,7 +115,7 @@ class Manager:
                 if not self.model or force_reload:
                         self.model = gtk.TreeStore(str, str, object)
                         self.model.set_sort_column_id(self.SORT_COLUMN, gtk.SORT_ASCENDING)
-                        manager = self.get_language_manager()
+                        manager = get_language_manager()
                         langs = gedit.language_manager_list_languages_sorted(manager, True)
                         
                         piter = self.model.append(None, (_('Global'), '', None))
@@ -157,20 +159,25 @@ class Manager:
                 tree_view.expand_row(self.model.get_path(expand), False)
                 self.select_iter(expand)
 
+        def get_cell_data_pixbuf_cb(self, column, cell, model, iter):
+                s = model.get_value(iter, self.OBJ_COLUMN)
+                
+                snippet = isinstance(s, SnippetData)
+                
+                if snippet and not s.valid:
+                        cell.set_property('stock-id', gtk.STOCK_DIALOG_ERROR)
+                else:
+                        cell.set_property('stock-id', None)
+
+                cell.set_property('xalign', 1.0)
+                
         def get_cell_data_cb(self, column, cell, model, iter):
                 s = model.get_value(iter, self.OBJ_COLUMN)
                 
                 snippet = isinstance(s, SnippetData)
                 
                 cell.set_property('editable', snippet)
-                
-                if snippet and not s.valid:
-                        cell.set_property('foreground-gdk', gdk.color_parse('red'))
-                else:
-                        cell.set_property('foreground-set', False)
-                
                 cell.set_property('markup', model.get_value(iter, self.NAME_COLUMN))
-                
 
         def on_tree_view_drag_data_get(self, widget, context, selection_data, info, time):
                 gfile = gio.File(self._temp_export)
@@ -256,10 +263,15 @@ class Manager:
                 self.tree_view = self['tree_view_snippets']
                 
                 self.column = gtk.TreeViewColumn(None)
+
                 self.renderer = gtk.CellRendererText()
                 self.column.pack_start(self.renderer, False)
                 self.column.set_cell_data_func(self.renderer, self.get_cell_data_cb)
-                
+
+                renderer = gtk.CellRendererPixbuf()
+                self.column.pack_start(renderer, True)
+                self.column.set_cell_data_func(renderer, self.get_cell_data_pixbuf_cb)
+
                 self.tree_view.append_column(self.column)
                 
                 self.renderer.connect('edited', self.on_cell_edited)
@@ -271,21 +283,9 @@ class Manager:
                 
                 self.build_dnd()
         
-        def get_language_manager(self):
-                if not self.manager:
-                        dirs = []
-                
-                        for d in Library().systemdirs:
-                                dirs.append(os.path.join(d, 'lang'))
-                
-                        self.manager = gsv.LanguageManager()
-                        self.manager.set_search_path(dirs + self.manager.get_search_path())
-                
-                return self.manager
-                
         def build(self):
                 self.builder = gtk.Builder()
-                self.builder.add_from_file(os.path.dirname(__file__) + '/snippets.ui')
+                self.builder.add_from_file(os.path.join(self.datadir, 'ui', 'snippets.ui'))
                 
                 handlers_dic = {
                         'on_dialog_snippets_response': self.on_dialog_snippets_response,
@@ -312,16 +312,18 @@ class Manager:
                 image.set_from_stock(gtk.STOCK_REMOVE, gtk.ICON_SIZE_SMALL_TOOLBAR)
 
                 source_view = self['source_view_snippet']
-                source_view.modify_font(pango.FontDescription('Monospace 8'))
-                manager = self.get_language_manager()
+                manager = get_language_manager()
                 lang = manager.get_language('snippets')
 
                 if lang:
                         source_view.get_buffer().set_highlight_syntax(True)
                         source_view.get_buffer().set_language(lang)
                         self.snippets_doc = Document(None, source_view)
-                                
-                entry = self['combo_drop_targets'].child
+
+                combo = self['combo_drop_targets']
+                combo.set_text_column(0)
+
+                entry = combo.child
                 entry.connect('focus-out-event', self.on_entry_drop_targets_focus_out)
                 entry.connect('drag-data-received', self.on_entry_drop_targets_drag_data_received)
                 
@@ -330,6 +332,9 @@ class Manager:
                 entry.drag_dest_set_target_list(lst)
                 
                 self.dlg = self['dialog_snippets']
+                
+                if self.default_size:
+                        self.dlg.set_default_size(*self.default_size)
         
         def __getitem__(self, key):
                 return self.builder.get_object(key)
@@ -406,7 +411,7 @@ class Manager:
                                 image_remove.set_from_stock(gtk.STOCK_DELETE, gtk.ICON_SIZE_BUTTON)
                                 tooltip = _('Delete selected snippet')
                         
-                        self.tooltips.set_tip(button_remove, tooltip)
+                        button_remove.set_tooltip_text(tooltip)
 
         def snippet_changed(self, piter = None):
                 if piter:
@@ -433,7 +438,7 @@ class Manager:
         def run(self):
                 if not self.dlg:
                         self.build()
-                        self.dlg.show_all()
+                        self.dlg.show()
                 else:
                         self.build_model()
                         self.dlg.present()
@@ -514,11 +519,13 @@ class Manager:
                         sens = False
 
                         self['entry_tab_trigger'].set_text('')
-                        self['entry_accelerator'].set_text('')                        
-                        self['source_view_snippet'].get_buffer().set_text('')
+                        self['entry_accelerator'].set_text('')
+                        buf = self['source_view_snippet'].get_buffer()
+                        buf.begin_not_undoable_action()
+                        buf.set_text('')
+                        buf.end_not_undoable_action()
                         self['combo_drop_targets'].child.set_text('')
 
-                        self.tooltips.disable()
                 else:
                         sens = True
 
@@ -528,9 +535,10 @@ class Manager:
                         self['combo_drop_targets'].child.set_text(', '.join(self.snippet['drop-targets']))
                         
                         buf = self['source_view_snippet'].get_buffer()
+                        buf.begin_not_undoable_action()
                         buf.set_text(self.snippet['text'])
-                        
-                        self.tooltips.enable()
+                        buf.end_not_undoable_action()
+
 
                 for name in ['source_view_snippet', 'label_tab_trigger',
                                 'entry_tab_trigger', 'label_accelerator', 
@@ -600,6 +608,7 @@ class Manager:
                 if self.snippets_doc:
                         self.snippets_doc.stop()
                 
+                self.default_size = [dlg.allocation.width, dlg.allocation.height]
                 self.manager = None
 
                 self.unref_languages()        
@@ -665,17 +674,19 @@ class Manager:
                 text = entry.get_text()
                 
                 if text and not Library().valid_tab_trigger(text):
-                        entry.modify_base(gtk.STATE_NORMAL, gtk.gdk.Color(0xffff, 0x6666, \
-                                        0x6666))
-                        entry.modify_text(gtk.STATE_NORMAL, gtk.gdk.Color(0xffff, 0xffff, \
-                                        0xffff))
+                        img = self['image_tab_trigger']
+                        img.set_from_stock(gtk.STOCK_DIALOG_ERROR, gtk.ICON_SIZE_BUTTON)
+                        img.show()
 
-                        self.tooltips.set_tip(entry, _('This is not a valid tab trigger. Triggers can either contain letters or a single, non alphanumeric, character like {, [, etcetera.'))
+                        #self['hbox_tab_trigger'].set_spacing(3)
+                        tip = _('This is not a valid Tab trigger. Triggers can either contain letters or a single (non-alphanumeric) character like: {, [, etc.')
+                        
+                        entry.set_tooltip_text(tip)
+                        img.set_tooltip_text(tip)
                 else:
-                        entry.modify_base(gtk.STATE_NORMAL, None)
-                        entry.modify_text(gtk.STATE_NORMAL, None)
-
-                        self.tooltips.set_tip(entry, _('Single word with which the snippet is activated after pressing tab'))
+                        self['image_tab_trigger'].hide()
+                        #self['hbox_tab_trigger'].set_spacing(0)
+                        entry.set_tooltip_text(_('Single word the snippet is activated with after pressing Tab'))
                 
                 return False
 
@@ -754,11 +765,12 @@ class Manager:
                 success = True
                 
                 for filename in filenames:
-                        if not gedit.utils.uri_has_file_scheme(filename):
+                        gfile = gio.File(filename)
+
+                        if not gedit.utils.location_has_file_scheme(gfile):
                                 continue
 
                         # Remove file://
-                        gfile = gio.File(filename)
                         filename = gfile.get_path()
 
                         importer = Importer(filename)
@@ -772,7 +784,7 @@ class Manager:
                 self.build_model(True)
 
                 if success:
-                        message = _('Import succesfully completed')
+                        message = _('Import successfully completed')
                         message_dialog(self.dlg, gtk.MESSAGE_INFO, message)
                
         def on_import_response(self, dialog, response):
@@ -793,7 +805,7 @@ class Manager:
                 
                 dlg.add_filter(self.file_filter(_('All supported archives'), ('*.gz','*.bz2','*.tar', '*.xml')))
                 dlg.add_filter(self.file_filter(_('Gzip compressed archive'), ('*.tar.gz',)))
-                dlg.add_filter(self.file_filter(_('Bzip compressed archive'), ('*.tar.bz2',)))
+                dlg.add_filter(self.file_filter(_('Bzip2 compressed archive'), ('*.tar.bz2',)))
                 dlg.add_filter(self.file_filter(_('Single snippets file'), ('*.xml',)))
                 dlg.add_filter(self.file_filter(_('All files'), '*'))
 
@@ -811,7 +823,7 @@ class Manager:
                         msgtype = gtk.MESSAGE_ERROR
                         retval = False
                 else:
-                        message = _('Export succesfully completed')
+                        message = _('Export successfully completed')
                         msgtype = gtk.MESSAGE_INFO
                         retval = True
 
@@ -879,7 +891,7 @@ class Manager:
                         dlg._export_snippets = export_snippets
                         dlg.add_filter(self.file_filter(_('All supported archives'), ('*.gz','*.bz2','*.tar')))
                         dlg.add_filter(self.file_filter(_('Gzip compressed archive'), ('*.tar.gz',)))
-                        dlg.add_filter(self.file_filter(_('Bzip compressed archive'), ('*.tar.bz2',)))
+                        dlg.add_filter(self.file_filter(_('Bzip2 compressed archive'), ('*.tar.bz2',)))
 
                         dlg.add_filter(self.file_filter(_('All files'), '*'))
                         dlg.set_do_overwrite_confirmation(True)
@@ -942,7 +954,7 @@ class Manager:
                 
                 dlg.add_filter(self.file_filter(_('All supported archives'), ('*.gz','*.bz2','*.tar')))
                 dlg.add_filter(self.file_filter(_('Gzip compressed archive'), ('*.tar.gz',)))
-                dlg.add_filter(self.file_filter(_('Bzip compressed archive'), ('*.tar.bz2',)))
+                dlg.add_filter(self.file_filter(_('Bzip2 compressed archive'), ('*.tar.bz2',)))
 
                 dlg.add_filter(self.file_filter(_('All files'), '*'))
                 dlg.set_do_overwrite_confirmation(True)
