@@ -115,13 +115,15 @@ language_row_activated (GtkTreeView *tree_view,
 }
 
 static void
-gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
+create_dialog (GeditSpellLanguageDialog *dlg,
+	       const gchar *data_dir)
 {
 	GtkWidget *error_widget;
 	GtkWidget *content;
 	gboolean ret;
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *column;
+	gchar *ui_file;
 	gchar *root_objects[] = {
 		"content",
 		NULL
@@ -143,33 +145,39 @@ gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
 
 	/* HIG defaults */
 	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 2); /* 2 * 5 + 2 = 12 */
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->action_area), 6);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+			     2); /* 2 * 5 + 2 = 12 */
+	gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dlg))),
+					5);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dlg))),
+			     6);
 
 	g_signal_connect (dlg,
 			  "response",
 			  G_CALLBACK (dialog_response_handler),
 			  NULL);
 
-	ret = gedit_utils_get_ui_objects (GEDIT_UIDIR "languages-dialog.ui",
+	ui_file = g_build_filename (data_dir, "languages-dialog.ui", NULL);
+	ret = gedit_utils_get_ui_objects (ui_file,
 					  root_objects,	
 					  &error_widget,
 					  "content", &content,
 					  "languages_treeview", &dlg->languages_treeview,
 					  NULL);
-
+	g_free (ui_file);
+	
 	if (!ret)
 	{
 		gtk_widget_show (error_widget);
 
-		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dlg)->vbox),
-					     error_widget);
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+		                    error_widget,
+		                    TRUE, TRUE, 0);
 
 		return;
 	}
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 			    content, TRUE, TRUE, 0);
 	g_object_unref (content);
 	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
@@ -207,6 +215,12 @@ gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
 			  dlg);
 }
 
+static void
+gedit_spell_language_dialog_init (GeditSpellLanguageDialog *dlg)
+{
+	
+}
+
 static void
 populate_language_list (GeditSpellLanguageDialog        *dlg,
 			const GeditSpellCheckerLanguage *cur_lang)
@@ -249,7 +263,8 @@ populate_language_list (GeditSpellLanguageDialog        *dlg,
 
 GtkWidget *
 gedit_spell_language_dialog_new (GtkWindow                       *parent,
-				 const GeditSpellCheckerLanguage *cur_lang)
+				 const GeditSpellCheckerLanguage *cur_lang,
+				 const gchar *data_dir)
 {
 	GeditSpellLanguageDialog *dlg;
 
@@ -257,6 +272,8 @@ gedit_spell_language_dialog_new (GtkWindow                       *parent,
 
 	dlg = g_object_new (GEDIT_TYPE_SPELL_LANGUAGE_DIALOG, NULL);
 
+	create_dialog (dlg, data_dir);
+
 	populate_language_list (dlg, cur_lang);
 
 	gtk_window_set_transient_for (GTK_WINDOW (dlg), parent);
@@ -290,3 +307,4 @@ gedit_spell_language_get_selected_language (GeditSpellLanguageDialog *dlg)
 	return lang;
 }
 
+/* ex:ts=8:noet: */
