@@ -719,7 +719,6 @@ get_format_from_list (GtkWidget *listview)
 	GtkTreeModel *model;
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
-        gint selected_value;
 
 	gedit_debug (DEBUG_PLUGINS);
 
@@ -731,12 +730,16 @@ get_format_from_list (GtkWidget *listview)
 
 	if (gtk_tree_selection_get_selected (selection, NULL, &iter))
 	{
+	        gint selected_value;
+
 		gtk_tree_model_get (model, &iter, COLUMN_INDEX, &selected_value, -1);
+
+		gedit_debug_message (DEBUG_PLUGINS, "Sel value: %d", selected_value);
+
+	        return selected_value;
 	}
 
-	gedit_debug_message (DEBUG_PLUGINS, "Sel value: %d", selected_value);
-
-        return selected_value;
+	g_return_val_if_reached (0);
 }
 
 static TimeConfigureDialog *
@@ -773,9 +776,11 @@ get_configure_dialog (GeditTimePlugin *plugin)
 
 	/* HIG defaults */
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), 2); /* 2 * 5 + 2 = 12 */
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->action_area), 6);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog))),
+			     2); /* 2 * 5 + 2 = 12 */
+	gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dialog->dialog))),
+					5);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dialog->dialog))), 6);
 
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
@@ -799,8 +804,9 @@ get_configure_dialog (GeditTimePlugin *plugin)
 
 	if (!ret)
 	{
-		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
-					     error_widget);
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog))),
+		                    error_widget,
+		                    TRUE, TRUE, 0);
 		gtk_container_set_border_width (GTK_CONTAINER (error_widget), 5);
 
 		gtk_widget_show (error_widget);
@@ -852,7 +858,7 @@ get_configure_dialog (GeditTimePlugin *plugin)
 	/* setup a window of a sane size. */
 	gtk_widget_set_size_request (GTK_WIDGET (viewport), 10, 200);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog->dialog))),
 			    content, FALSE, FALSE, 0);
 	g_object_unref (content);
 	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
@@ -934,7 +940,7 @@ get_choose_format_dialog (GtkWindow                 *parent,
 	GtkWindowGroup *wg = NULL;
 	
 	if (parent != NULL)
-		wg = parent->group;
+		wg = gtk_window_get_group (parent);
 
 	dialog = g_new0 (ChooseFormatDialog, 1);
 
@@ -1264,3 +1270,4 @@ gedit_time_plugin_class_init (GeditTimePluginClass *klass)
 
 	g_type_class_add_private (object_class, sizeof (GeditTimePluginPrivate));
 }
+/* ex:ts=8:noet: */
