@@ -73,6 +73,9 @@ test_consecutive_write (const gchar *inbuf,
 	g_free (b);
 
 	g_assert (gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)) == FALSE);
+
+	g_object_unref (doc);
+	g_object_unref (out);
 }
 
 static void
@@ -129,3 +132,4 @@ int main (int   argc,
 
 	return g_test_run ();
 }
+/* ex:ts=8:noet: */
